==> snapconnect_futures-4.0.1a3-py2-none-any.whl: snapconnect_futures/responses.py <==
"""Objects that futures can resolve to in FSC."""


class MultiResult(object):
    def __init__(self, responses, unprocessed, invalid_responses=None, attempts_remaining=None):
        """Create a MultiResponse object

        :param dict[str, tuple|None] responses: Map from address to response tuple, or None if the node failed
        :param list[str] unprocessed: Addresses that were not processed as part of this response
        :param dict[str, tuple] invalid_responses: Map from address to response tuple when the response does not have
                                                   the correct number of arguments.  This address will also appear in the
                                                   responses dictionary, but the value will be set to None as if the message
                                                   had not succeeded.
        :param dict[str, int] attempts_remaining: Map from address to the number of attempts remaining for that node.
                                                  Used during chunked responses.
        """
        self.responses = responses  # Total responses
        self.unprocessed = unprocessed  # Total unprocessed
        self.invalid_responses = invalid_responses or {}  # Total invalid responses

        # Used when MultiResult is part of a chunked response
        self._retry = lambda: None  # Retry callback.  By default, just return None
        self.chunk_responses = responses  # Responses just for this chunk
        self.attempts_remaining = attempts_remaining or {}

    def __repr__(self):
        return "<MultiResult OK: %r, FAIL: %r, INVALID: %r, REMAINING: %r>" % (self.successful, self.failed, self.invalid_responses, self.attempts_remaining)

    @property
    def successful(self):
        """Return a dictionary of all successful responses and their values."""
        return {addr: response for addr, response in self.responses.iteritems() if response is not None}

    @property
    def failed(self):
        """Return a list of all failed addresses."""
        return [addr for addr, response in self.responses.iteritems() if response is None]

    def retry(self):
        """Return a retry future for the next dmcast.

        :rtype: MultiResult

        The future immediately resolves to None if there is nothing to retry
        If we have something to retry, the Future resolves to another MultiResult object.
        """
        return self._retry()

    def set_retry(self, retry):
        """Set the retry function for this MutliResult"""
        self._retry = retry

    def __iter__(self):
        """Backwards compatibility method.

        Used to allow method calls in the following format:
            responses, unprocessed = MultiResult(...)
        """
        yield self.responses
        yield self.unprocessed

==> snapconnect_futures-7.1.0-py2-none-any.whl: snapconnect_futures/responses.py <==
"""Objects that futures can resolve to in FSC."""


class MultiResult(object):
    def __init__(self, responses, unprocessed, invalid_responses=None, attempts_remaining=None):
        """Create a MultiResponse object

        Args:
            responses (dict[str, tuple | None]): Map from address to response tuple,
                None if the node failed
            unprocessed (list[str]): Addresses that were not processed as part of this response
            invalid_responses (dict[str, tuple]): Map from address to response tuple when the response does not have
                the correct number of arguments.  This address will also appear in the responses dictionary,
                but the value will be set to None as if the message ad not succeeded.
            attempts_remaining (dict[str, int]): Map from address to the number of attempts remaining for that node.
                Used during chunked responses.
        """
        self.responses = responses  # Total responses
        self.unprocessed = unprocessed  # Total unprocessed
        self.invalid_responses = invalid_responses or {}  # Total invalid responses

        # Used when MultiResult is part of a chunked response
        self._retry = lambda: None  # Retry callback.  By default, just return None
        self.chunk_responses = responses  # Responses just for this chunk
        self.attempts_remaining = attempts_remaining or {}

    def __repr__(self):
        return "<MultiResult OK: %r, FAIL: %r, INVALID: %r, REMAINING: %r>" % (self.successful, self.failed, self.invalid_responses, self.attempts_remaining)

    @property
    def successful(self):
        """Return a dictionary of all successful responses and their values."""
        return {addr: response for addr, response in self.responses.iteritems() if response is not None}

    @property
    def failed(self):
        """Return a list of all failed addresses."""
        return [addr for addr, response in self.responses.iteritems() if response is None]

    def retry(self):
        """Return a retry future for the next dmcast.

        Returns:
            MultiResult: The future immediately resolves to None if there is nothing to retry
                If we have something to retry, the Future resolves to another MultiResult object.
        """
        return self._retry()

    def set_retry(self, retry):
        """Set the retry function for this MutliResult"""
        self._retry = retry

    def __iter__(self):
        """Backwards compatibility method.

        Used to allow method calls in the following format:
            responses, unprocessed = MultiResult(...)
        """
        yield self.responses
        yield self.unprocessed
